
# Type: chemical to chemical association_object




URI: [biolink:chemical_to_chemical_association_object](https://w3id.org/biolink/vocab/chemical_to_chemical_association_object)


## Domain and Range

[ChemicalToChemicalAssociation](ChemicalToChemicalAssociation.md) ->  <sub>REQ</sub> [ChemicalSubstance](ChemicalSubstance.md)

## Parents

 *  is_a: [object](object.md)

## Children

 *  [chemical to chemical derivation association➞object](chemical_to_chemical_derivation_association_object.md)

## Used by

 * [ChemicalToChemicalAssociation](ChemicalToChemicalAssociation.md)
